% recalculate the statistics shown in the paper

EXP2 = load('human_cotraining_exp2_data.csv');

fprintf('rows: CS, CI, FS, FI, NS, NI\n');
fprintf('columns: cross horz vert diag other\n');

sid.gabor_cotr = unique(EXP2(find(EXP2(:,1) == 1),2));
sid.gabor_full = unique(EXP2(find(EXP2(:,1) == 2),2));
sid.gabor_none = unique(EXP2(find(EXP2(:,1) == 3),2));
sid.color_cotr = unique(EXP2(find(EXP2(:,1) == 4),2));
sid.color_full = unique(EXP2(find(EXP2(:,1) == 5),2));
sid.color_none = unique(EXP2(find(EXP2(:,1) == 6),2));

n.gabor_cotr = length(sid.gabor_cotr);
n.gabor_full = length(sid.gabor_full);
n.gabor_none = length(sid.gabor_none);
n.color_cotr = length(sid.color_cotr);
n.color_full = length(sid.color_full);
n.color_none = length(sid.color_none);

majVoteClusterCats.gabor_cotr = [];
majVoteClusterCats.gabor_full = [];
majVoteClusterCats.gabor_none = [];
majVoteClusterCats.color_cotr = [];
majVoteClusterCats.color_full = [];
majVoteClusterCats.color_none = [];

majVotePatternProportions.gabor_cotr = [];
majVotePatternProportions.gabor_full = [];
majVotePatternProportions.gabor_none = [];
majVotePatternProportions.color_cotr = [];
majVotePatternProportions.color_full = [];
majVotePatternProportions.color_none = [];

cross_pattern = [-1 1 -1  1];
vert_pattern  = [-1 1  1  1];
horz_pattern  = [-1 1 -1 -1];
diag_pattern  = [-1 1  1 -1];

% starting with gabor cotraining, determine majority vote cluster behavior

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.gabor_cotr)

  % get subject id
  s = sid.gabor_cotr(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.gabor_cotr(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.gabor_cotr(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.gabor_cotr
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.gabor_cotr = [cross horz vert diag other]/n.gabor_cotr;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.gabor_cotr);


% color cotraining

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.color_cotr)

  % get subject id
  s = sid.color_cotr(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.color_cotr(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.color_cotr(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.color_cotr(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.color_cotr(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.color_cotr(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.color_cotr
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.color_cotr = [cross horz vert diag other]/n.color_cotr;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.color_cotr);



% gabor full

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.gabor_full)

  % get subject id
  s = sid.gabor_full(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.gabor_full(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.gabor_full(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.gabor_full(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.gabor_full(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.gabor_full(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.gabor_full
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.gabor_full = [cross horz vert diag other]/n.gabor_full;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.gabor_full);


% color full

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.color_full)

  % get subject id
  s = sid.color_full(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.color_full(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.color_full(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.color_full(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.color_full(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.color_full(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.color_full
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.color_full = [cross horz vert diag other]/n.color_full;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.color_full);


% gabor none

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.gabor_none)

  % get subject id
  s = sid.gabor_none(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.gabor_none(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.gabor_none(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.gabor_none(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.gabor_none(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.gabor_none(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.gabor_none
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.gabor_none = [cross horz vert diag other]/n.gabor_none;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.gabor_none);


% color none

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.color_none)

  % get subject id
  s = sid.color_none(i);

  % get subject results
  r = EXP2(find(EXP2(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3);
  c2 = find(r(:,2) > .7);
  c3 = find(r(:,1) > .7);
  c4 = find(r(:,2) < .3);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.color_none(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.color_none(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.color_none(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.color_none(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.color_none(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.color_none
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.color_none = [cross horz vert diag other]/n.color_none;
fprintf('%0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.color_none);

clear r s cross horz vert diag other m cat i j p
