% recalculate the statistics found in the paper

EXP3 = load('human_cotraining_exp3_data.csv');

sid.gabor_cotr = unique(EXP3(find(EXP3(:,1) == 1),2));

n.gabor_cotr = length(sid.gabor_cotr);

majVoteClusterCats.gabor_cotr = [];

majVotePatternProportions.gabor_cotr = [];

cross_pattern = [-1 1 -1  1];
vert_pattern  = [-1 1  1  1];
horz_pattern  = [-1 1 -1 -1];
diag_pattern  = [-1 1  1 -1];

% gabor cotraining, determine majority vote cluster behavior

cross = 0;
horz = 0;
vert = 0;
diag = 0;
other = 0;

for i = 1:length(sid.gabor_cotr)

  % get subject id
  s = sid.gabor_cotr(i);

  % get subject results
  r = EXP3(find(EXP3(:,2) == s),3:end);

  % determine categorizations from x1 point of view
  cat = [];
  for j = 1:size(r,1)
    if r(j,3) ~= 0
      % labeled examples
      cat(j) = r(j,3);
    elseif r(j,4) ~= 0 
      % x1 labeled examples
      cat(j) = r(j,4);
    elseif r(j,4) == 0 & r(j,6) ~= 0
      % x2 labeled examples
      cat(j) = r(j,6);
    else
      fprintf('ERROR: %d bad class label for r(%d)\n',s,j);
    end
  end

  % determine clusters
  c1 = find(r(:,1) < .3 & r(:,2) > .3 & r(:,2) < .7 & r(:,3) == 0);
  c2 = find(r(:,2) > .7 & r(:,1) > .3 & r(:,1) < .7 & r(:,3) == 0);
  c3 = find(r(:,1) > .7 & r(:,2) > .3 & r(:,2) < .7);
  c4 = find(r(:,2) < .3 & r(:,1) > .3 & r(:,1) < .7);

  % calculate majority vote

  if length(find(cat(c1) == -1)) > length(find(cat(c1) == 1))
    m(1) = -1;
  elseif length(find(cat(c1) == -1)) < length(find(cat(c1) == 1))
    m(1) = 1;
  else
    m(1) = 0;
  end

  if length(find(cat(c2) == -1)) > length(find(cat(c2) == 1))
    m(2) = -1;
  elseif length(find(cat(c2) == -1)) < length(find(cat(c2) == 1))
    m(2) = 1;
  else
    m(2) = 0;
  end

  if length(find(cat(c3) == -1)) > length(find(cat(c3) == 1))
    m(3) = -1;
  elseif length(find(cat(c3) == -1)) < length(find(cat(c3) == 1))
    m(3) = 1;
  else
    m(3) = 0;
  end

  if length(find(cat(c4) == -1)) > length(find(cat(c4) == 1))
    m(4) = -1;
  elseif length(find(cat(c4) == -1)) < length(find(cat(c4) == 1))
    m(4) = 1;
  else
    m(4) = 0;
  end

  majVoteClusterCats.gabor_cotr(end+1,:) = m;

  % determine pattern match
  if sum(majVoteClusterCats.gabor_cotr(end,:) == cross_pattern) == 4
    cross = cross + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == horz_pattern) == 4
    horz = horz + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == vert_pattern) == 4
    vert = vert + 1;
  elseif sum(majVoteClusterCats.gabor_cotr(end,:) == diag_pattern) == 4
    diag = diag + 1;
  else
    other = other + 1;
  end
end

if cross+horz+vert+diag+other ~= n.gabor_cotr
  fprintf('ERROR: mismatching number of results\n');
end

majVotePatternProportions.gabor_cotr = [cross horz vert diag other]/n.gabor_cotr;
fprintf('columns: cross horz vert diag other\n');
fprintf('mean majority vote: %0.2f %0.2f %0.2f %0.2f %0.2f\n',majVotePatternProportions.gabor_cotr);


